#
# spec file for package wxsqlite3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define wx_version_pkgname %(wx-config --version | sed 's@^\\([^\\.]\\+\\.[^\\.]\\+\\)\\(.*\\)@\\1@;s@\\.@_@')
%define wx_version_soname  %(wx-config --version | sed 's@^\\([^\\.]\\+\\.[^\\.]\\+\\)\\(.*\\)@\\1@')
%define sover 0
%if 0%{?suse_version} > 1315
BuildRequires:  wxWidgets-devel >= 3
%else
%define _use_internal_dependency_generator 0
%define __find_requires %{wx_requires}
BuildRequires:  wxWidgets-3_0-devel
%endif
Name:           wxsqlite3
Version:        4.9.11
Release:        1.1
Summary:        C++ wrapper around SQLite 3.x
License:        SUSE-wxWidgets-3.1
URL:            https://github.com/utelle/wxsqlite3
Source0:        https://github.com/utelle/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf >= 2.69
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool

%description
wxSQLite3 is a C++ wrapper around the public domain SQLite 3.x database
and is specifically designed for use in programs based on the wxWidgets
library.

%package -n libwxcode_gtk2u_wxsqlite3-%{wx_version_pkgname}-%{sover}
Summary:        C++ wrapper around SQLite 3.x

%description -n libwxcode_gtk2u_wxsqlite3-%{wx_version_pkgname}-%{sover}
wxSQLite3 is a C++ wrapper around the public domain SQLite 3.x database
and is specifically designed for use in programs based on the wxWidgets
library.

%package        devel
Summary:        C++ wrapper around SQLite 3.x - Development Files
Requires:       libwxcode_gtk2u_wxsqlite3-%{wx_version_pkgname}-%{sover} = %{version}

%description    devel
wxSQLite3 is a C++ wrapper around the public domain SQLite 3.x database
and is specifically designed for use in programs based on the wxWidgets
library.

%prep
: wx_version_pkgname: %{wx_version_pkgname}
: wx_version_soname: %{wx_version_soname}
wx-config --version
%autosetup

%build
CFLAGS='%{optflags} -Wno-unused-but-set-variable -Wno-unused-variable -Wno-unused-function'
CXXFLAGS="${CFLAGS}"
autoreconf -fi
%configure \
	--enable-shared \
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libwxcode_gtk2u_wxsqlite3-%{wx_version_pkgname}-%{sover} -p /sbin/ldconfig
%postun -n libwxcode_gtk2u_wxsqlite3-%{wx_version_pkgname}-%{sover} -p /sbin/ldconfig

%files -n libwxcode_gtk2u_wxsqlite3-%{wx_version_pkgname}-%{sover}
%license LICENCE.txt
%doc readme.md
%{_libdir}/libwxcode_gtk2u_wxsqlite3-%{wx_version_soname}.so.%{sover}*

%files devel
%license LICENCE.txt
%dir %{_includedir}/wx
%{_includedir}/wx/wxsqlite3.h
%{_includedir}/wx/wxsqlite3_version.h
%{_includedir}/wx/wxsqlite3def.h
%{_libdir}/libwxcode_gtk2u_wxsqlite3-%{wx_version_soname}.so
%{_libdir}/pkgconfig/wxsqlite3.pc

%changelog
* Tue Jul  2 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- Update to 4.9.11
  * Upgrade to SQLite3 Multiple Ciphers version 1.8.6 (based on SQLite 3.46.0)
- Update to 4.9.10
  * Upgrade to SQLite3 Multiple Ciphers version 1.8.4 (based on SQLite 3.45.2)
  * Disable user authentication extension in build files by default
- Update to 4.9.9
  * Upgrade to SQLite3 Multiple Ciphers version 1.8.2 (based on SQLite 3.45.0)
- Update to 4.9.8
  * Upgrade to SQLite3 Multiple Ciphers version 1.8.0 (based on SQLite 3.44.1)
  * Added new cipher scheme Ascon-128 (Lightweight Authenticated Encryption)
- Update to 4.9.7
  * Upgrade to SQLite3 Multiple Ciphers version 1.7.4 (based on SQLite 3.44.0)
  * Prevent crashes due to uninitialized cipher tables
* Fri Oct  6 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.9.6
  * Upgrade to SQLite3 Multiple Ciphers version 1.7.0 (based on SQLite 3.43.1)
  * Enhance method wxSQLite3Database::Open allowing to set the VFS to be used
  * Add method wxSQLite3Database::IsInterrupted
* Thu Feb  9 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 4.9.1:
  * Upgrade to SQLite3 Multiple Ciphers version 1.5.4 (SQLite version 3.40.0)
  * fixed issue wxSQLite3Database::SetJournalMode always returns DELETE
* Mon May  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 4.8.1:
  * Upgrade to SQLite3 Multiple Ciphers version 1.4.3 (based on SQLite 3.38.5)
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.7.2
  * Added method wxSQLite3Database::QueryTransactionState
  * Upgrade to SQLite3 Multiple Ciphers version 1.3.2
  * Based on SQLite 3.35.5
  * Enabled new SQLite Math Extension
  * Fixed a memory leak in method wxSQLite3Database::GetTable
  * WAL journals left behind by versions <= 1.2.5 are not
    compatible with this new implementation. To be able to access
    WAL journals created by prior versions, the configuration
    parameter mc_legacy_wal was introduced.
* Tue Oct 13 2020 olaf@aepfle.de
- Update to version 4.6.1.
  No changelog provided by upstream
* Sat Feb  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.5.1. Too many changes to list, see
  https://github.com/utelle/wxsqlite3#history
- Drop _service file
- Spec cleanup
* Fri Nov  3 2017 olaf@aepfle.de
- Version 3.5.8.20171102.1b93c9c
  Fixed an issue with SQLite savepoints, if the savepoint name
  contained special characters. Savepoint names are now always quoted.
* Fri Mar 31 2017 olaf@aepfle.de
- Version 3.5.3.20170331.3494a8b
* Sun Mar 19 2017 olaf@aepfle.de
- Version 3.5.2.20170319.e79d1ef
* Wed Feb 22 2017 olaf@aepfle.de
- Initial version 3.5.1.20170216.2927d43
